@@ -7,6 +7,7 @@
 */
 
 #include "aboutdata.h"
+#include "config-kaddressbook.h"
 #include "kaddressbook_options.h"
 #include "mainwidget.h"
 #include "mainwindow.h"
@@ -16,19 +17,13 @@
 
 #include "kaddressbook_debug.h"
 #include <kontactinterface/pimuniqueapplication.h>
-#ifdef WITH_KUSERFEEDBACK
+#if KADDRESSBOOK_WITH_KUSERFEEDBACK
 #include "userfeedback/kaddressbookuserfeedbackprovider.h"
 #endif
 
-#define HAVE_KICONTHEME __has_include(<KIconTheme>)
-#if HAVE_KICONTHEME
 #include <KIconTheme>
-#endif
 
-#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
-#if HAVE_STYLE_MANAGER
 #include <KStyleManager>
-#endif
 
 //-----------------------------------------------------------------------------
 
@@ -58,19 +53,11 @@ int KAddressBookApplication::activate(const QStringList &arguments, const QStrin
 
 int main(int argc, char **argv)
 {
-#if HAVE_KICONTHEME
     KIconTheme::initTheme();
-#endif
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     KAddressBookApplication app(argc, &argv);
     app.setDesktopFileName(QStringLiteral("org.kde.kaddressbook"));
-#if HAVE_STYLE_MANAGER
     KStyleManager::initStyle();
-#else // !HAVE_STYLE_MANAGER
-#if defined(Q_OS_MACOS) || defined(Q_OS_WIN)
-    QApplication::setStyle(QStringLiteral("breeze"));
-#endif // defined(Q_OS_MACOS) || defined(Q_OS_WIN)
-#endif // HAVE_STYLE_MANAGER
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("kaddressbook"));
 
     AboutData about;
@@ -85,7 +72,7 @@ int main(int argc, char **argv)
     cmdArgs->process(args);
     about.processCommandLine(cmdArgs);
 
-#ifdef WITH_KUSERFEEDBACK
+#if KADDRESSBOOK_WITH_KUSERFEEDBACK
     if (cmdArgs->isSet(QStringLiteral("feedback"))) {
         auto userFeedBack = new KAddressBookUserFeedbackProvider(nullptr);
         QTextStream(stdout) << userFeedBack->describeDataSources() << '\n';
